@@ -110,9 +110,9 @@ async def upload_without_progress_bar(client, entity, file_location, name=None,
 
 def progress_bar_str(done, total):
     percent = round(done/total*100, 2)
-    strin = "░░░░░░░░░░░░░░░░░░░░"
+    strin = "░░░░░░░░░░"
     strin = list(strin)
-    for i in range(round(percent)//5):
+    for i in range(round(percent)//10):
         strin[i] = "█"
     strin = "".join(strin)
     final = f"Percent: {percent}%\n{human_readable_size(done)}/{human_readable_size(total)}\n{strin}"
